summaryrefslogtreecommitdiffstats
path: root/jjb/fuel/fuel-deploy.sh
diff options
context:
space:
mode:
Diffstat (limited to 'jjb/fuel/fuel-deploy.sh')
-rwxr-xr-xjjb/fuel/fuel-deploy.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/jjb/fuel/fuel-deploy.sh b/jjb/fuel/fuel-deploy.sh
index 418b814e5..dd89447e6 100755
--- a/jjb/fuel/fuel-deploy.sh
+++ b/jjb/fuel/fuel-deploy.sh
@@ -19,8 +19,8 @@ LAB_NAME=${NODE_NAME/-*}
# shellcheck disable=SC2153
POD_NAME=${NODE_NAME/*-}
-# Fuel currently supports arm, enea, ericsson, intel, lf, unh and zte labs
-if [[ ! "${LAB_NAME}" =~ (arm|enea|ericsson|intel|lf|unh|zte) ]]; then
+# Fuel currently supports arm, enea, ericsson, intel, lf, unh, zte and itri labs
+if [[ ! "${LAB_NAME}" =~ (arm|enea|ericsson|intel|lf|unh|zte|itri) ]]; then
echo "Unsupported/unidentified lab ${LAB_NAME}. Cannot continue!"
exit 1
fi